@@ -5,6 +5,10 @@
 #' returns a numeric vector that can be used to scale the nodes
 #' @param identify_function a function for the identification of a single node,
 #' e.g. max, min, mean, etc.
+#' @name ggtools
+NULL
+
+#' @rdname ggtools
 #' @examples
 #' ggidentify(brandes, node_degree)
 #' ggidentify(brandes, node_betweenness)
@@ -24,3 +28,20 @@ ggidentify <- function(object, node_measure, identify_function = max) {
                                 values = c("red", "blue")) +
     ggplot2::theme(legend.position = "none")
 }
+
+#' @rdname ggtools
+#' @examples
+#' ggdistrib(brandes, node_degree)
+#' ggdistrib(brandes, node_betweenness)
+#' ggdistrib(brandes, node_closeness)
+#' ggdistrib(brandes, node_eigenvector)
+#' @export
+ggdistrib <- function(object, node_measure){
+  distrib <- node_measure(object)
+  ggplot2::qplot(distrib, geom="histogram", 
+                 binwidth=ifelse(max(distrib)>1, 1, 
+                                 ifelse(max(distrib)>.1, .1, .01))) + 
+    ggplot2::theme_classic() +
+    ggplot2::xlab("Score") +
+    ggplot2::ylab("Frequency")
+}
